[gtk/wip.win32.fixes: 27/27] gdkcairocontext-win32.c: Unify parameter name




commit c8d71f9465bee2b788fdfeb1423542a38d003f41
Author: Chun-wei Fan <fanchunwei src gnome org>
Date:   Mon May 9 13:08:41 2022 +0800

    gdkcairocontext-win32.c: Unify parameter name
    
    Use "update_area" instead of "region" for gdk_win32_cairo_context_begin_frame()
    to be more consistent with the corresponding GdkDrawContext begin_frame()
    implementations for Windows EGL/WGL/Vulkan draw contexts.

 gdk/win32/gdkcairocontext-win32.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/gdk/win32/gdkcairocontext-win32.c b/gdk/win32/gdkcairocontext-win32.c
index 0a87c4031e..7837194820 100644
--- a/gdk/win32/gdkcairocontext-win32.c
+++ b/gdk/win32/gdkcairocontext-win32.c
@@ -54,7 +54,7 @@ create_cairo_surface_for_surface (GdkSurface *surface,
 static void
 gdk_win32_cairo_context_begin_frame (GdkDrawContext *draw_context,
                                      gboolean        prefers_high_depth,
-                                     cairo_region_t *region)
+                                     cairo_region_t *update_area)
 {
   GdkWin32CairoContext *self = GDK_WIN32_CAIRO_CONTEXT (draw_context);
   GdkSurface *surface;
@@ -100,7 +100,7 @@ gdk_win32_cairo_context_begin_frame (GdkDrawContext *draw_context,
       self->paint_surface = cairo_surface_reference (self->db_surface);
     }
 
   /* Clear the paint region.
    * For non-double-buffered rendering we must clear it, otherwise
    * semi-transparent pixels will "add up" with each repaint.
    * We must also clear the old pixels from the DB cache surface
@@ -109,7 +109,7 @@ gdk_win32_cairo_context_begin_frame (GdkDrawContext *draw_context,
   cr = cairo_create (self->paint_surface);
   cairo_set_source_rgba (cr, 0, 0, 0, 00);
   cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-  gdk_cairo_region (cr, region);
+  gdk_cairo_region (cr, update_area);
   cairo_clip (cr);
   cairo_paint (cr);
   cairo_destroy (cr);
@@ -100,7 +100,7 @@ gdk_win32_cairo_context_begin_frame (GdkDrawContext *draw_context,
     }
 
-  /* Clear the paint region.
+  /* Clear the paint region (update_area).
    * For non-double-buffered rendering we must clear it, otherwise
    * semi-transparent pixels will "add up" with each repaint.


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]